-- basket fruits state machine
beginStateMachine()
	
	onEnter(function(msg)
		local basket = getStateObjectFromID(msg.sender);
		storeStateObject("basket", basket);
		
		if (basket) then
			-- basket does exist
			local actionPointName = retrieveData("actionPointName");
			local actionPoint = getParent().getFreeActionPoint(basket, actionPointName);

			if exitIfWrongPosition(getParent(), basket, actionPointName) then return end;	

			if (not actionPoint) then
				-- action point is locked
				getParent().setEmoticon(EMOTICON_CANNOT, EMOTICON_DELAY);
				sendMsg("emoThink", getParent().walkSO);
				exitStateMachine();
			else
				getParent().lockActionPoints(basket);
			end
		else
			-- basket does not exist anymore
			getParent().setEmoticon(EMOTICON_CANNOT, EMOTICON_DELAY);
			sendMsg("emoThink", getParent().walkSO);
			exitStateMachine();
		end
		
		freeHands(getParent());
				
	end )
	
	onExit(function(msg)
		unlockAll("basket");		
		
		getParent().stopAllActivities();	
	end )
	
	-----------------------------------------------------------------------------------------
	-----------------------------------------------------------------------------------------
	-----------------------------------------------------------------------------------------
	
	
	state("eatFruitStart")
	
		onEnter(function(msg)
			local basket = retrieveStateObject("basket");
			if (basket.getZ() < 0.55) then
				startAnimation("eatFruitsLowStart");
			else
				startAnimation("eatFruitsStart");
			end
			
			sendDelayedMsgThis("grabApple", 800);
		end )	
			
		onMsg("grabApple", function(msg)
			local basket = retrieveStateObject("basket");			
			local apple = getParent().loadGameObject("StandardGO", "apple");
			getParent().attachRightObjectHolder(apple);			
		end )	


		onMsg("end", function(msg)
			if testCancel() then
				setState("eatFruitStop");
			else
				setState("eatFruit");
			end
		end )	

	state("eatFruit")
	
		onEnter(function(msg)
			startAnimation("eatFruitsLoop");
			
			local basket = retrieveStateObject("basket");			
			local eatFruit = getParent().startActivity("eatFruit", basket);
			local length, scale = getActivityLength(eatFruit);

			sendDelayedMsgThis("complete", length);
			sendDelayedMsgThis("testCancel", CANCEL_POLLING_INTERVAL);
			
			local apple = getParent().getRightHeldObject();
			apple.buy(); -- pay money for food
		end )
		
		onExit(function(msg)
			local basket = retrieveStateObject("basket");
			getParent().stopAllActivities(basket);
		end )

				
		onMsg("complete", function(msg)
			setState("eatFruitStop");
		end )			

		onMsg("testCancel", function(msg)
			if testCancel() then
				sendMsgThis("complete");
			else
				sendDelayedMsgThis("testCancel", CANCEL_POLLING_INTERVAL);
			end
		end )			


		onMsg("end", function(msg)
			if testCancel() then
				sendMsgThis("complete");
			else
				startAnimation("eatFruitsLoop");
			end
		end )	
		
		
	state("eatFruitStop")
	
		onEnter(function(msg)
			startAnimation("eatFruitsEnd");
			
			local apple = getParent().getRightHeldObject();
			if (apple) then
				getParent().detachRightObjectHolder();
				apple.deleteGameObject();
			end
			
			-- freeHands(getParent());
		end )
		

		onMsg("end", function(msg)
			exitAndGoAway();
		end )	

endStateMachine()
